---
title: <span class="badge object-type-scalar"></span> LocaleFormat
---
# <span class="badge object-type-scalar"></span> LocaleFormat

## Definition

```python
LocaleFormat: typing.Literal["locale"] = "locale"
```
